==> jupyterlab_jherng-0.1.1.tar.gz: jupyterlab_jherng-0.1.1/README.md <==
# jupyterlab_jherng

[![Github Actions Status](https://github.com/hongjiaherng/jupyterlab-jherng/workflows/Build/badge.svg)](https://github.com/hongjiaherng/jupyterlab-jherng/actions/workflows/build.yml)[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/hongjiaherng/jupyterlab-jherng/main?urlpath=lab)
A JupyterLab theme for me.

## Requirements

- JupyterLab >= 4.0.0

## Install

To install the extension, execute:

```bash
pip install jupyterlab_jherng
```

## Uninstall

To remove the extension, execute:

```bash
pip uninstall jupyterlab_jherng
```

## Contributing

### Development install

Note: You will need NodeJS to build the extension package.

The `jlpm` command is JupyterLab's pinned version of
[yarn](https://yarnpkg.com/) that is installed with JupyterLab. You may use
`yarn` or `npm` in lieu of `jlpm` below.

```bash
# Clone the repo to your local environment
# Change directory to the jupyterlab_jherng directory
# Install package in development mode
pip install -e "."
# Link your development version of the extension with JupyterLab
jupyter labextension develop . --overwrite
# Rebuild extension Typescript source after making changes
jlpm build
```

You can watch the source directory and run JupyterLab at the same time in different terminals to watch for changes in the extension's source and automatically rebuild the extension.

```bash
# Watch the source directory in one terminal, automatically rebuilding when needed
jlpm watch
# Run JupyterLab in another terminal
jupyter lab
```

With the watch command running, every saved change will immediately be built locally and available in your running JupyterLab. Refresh JupyterLab to load the change in your browser (you may need to wait several seconds for the extension to be rebuilt).

By default, the `jlpm build` command generates the source maps for this extension to make it easier to debug using the browser dev tools. To also generate source maps for the JupyterLab core extensions, you can run the following command:

```bash
jupyter lab build --minimize=False
```

### Development uninstall

```bash
pip uninstall jupyterlab_jherng
```

In development mode, you will also need to remove the symlink created by `jupyter labextension develop`
command. To find its location, you can run `jupyter labextension list` to figure out where the `labextensions`
folder is located. Then you can remove the symlink named `@jherng/jupyterlab-jherng` within that folder.

### Packaging the extension

See [RELEASE](RELEASE.md)

==> jupyterlab_jherng-0.1.3.tar.gz: jupyterlab_jherng-0.1.3/README.md <==
# jupyterlab-jherng

[![Github Actions Status](https://github.com/hongjiaherng/jupyterlab-jherng/workflows/Build/badge.svg)](https://github.com/hongjiaherng/jupyterlab-jherng/actions/workflows/build.yml)[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/hongjiaherng/jupyterlab-jherng/main?urlpath=lab)
[![pypi](https://img.shields.io/pypi/v/jupyterlab-jherng.svg)](https://pypi.org/project/jupyterlab-jherng/)
[![npm](https://img.shields.io/npm/v/@jherng/jupyterlab-jherng.svg)](https://www.npmjs.com/package/@jherng/jupyterlab-jherng)

A JupyterLab theme for me.

![jherng_preview](assets/jherng_preview.png)

## Requirements

- JupyterLab >= 4.0.0

## Install

To install the extension, execute:

```bash
pip install jupyterlab-jherng
```

## Uninstall

To remove the extension, execute:

```bash
pip uninstall jupyterlab-jherng
```

## Contributing

### Development install

Note: You will need NodeJS to build the extension package.

The `jlpm` command is JupyterLab's pinned version of
[yarn](https://yarnpkg.com/) that is installed with JupyterLab. You may use
`yarn` or `npm` in lieu of `jlpm` below.

```bash
# Clone the repo to your local environment
# Change directory to the jupyterlab-jherng directory
# Install package in development mode
pip install -e "."
# Link your development version of the extension with JupyterLab
jupyter labextension develop . --overwrite
# Rebuild extension Typescript source after making changes
jlpm build
```

You can watch the source directory and run JupyterLab at the same time in different terminals to watch for changes in the extension's source and automatically rebuild the extension.

```bash
# Watch the source directory in one terminal, automatically rebuilding when needed
jlpm watch
# Run JupyterLab in another terminal
jupyter lab
```

With the watch command running, every saved change will immediately be built locally and available in your running JupyterLab. Refresh JupyterLab to load the change in your browser (you may need to wait several seconds for the extension to be rebuilt).

By default, the `jlpm build` command generates the source maps for this extension to make it easier to debug using the browser dev tools. To also generate source maps for the JupyterLab core extensions, you can run the following command:

```bash
jupyter lab build --minimize=False
```

### Development uninstall

```bash
pip uninstall jupyterlab-jherng
```

In development mode, you will also need to remove the symlink created by `jupyter labextension develop`
command. To find its location, you can run `jupyter labextension list` to figure out where the `labextensions`
folder is located. Then you can remove the symlink named `@jherng/jupyterlab-jherng` within that folder.

### Packaging the extension

See [RELEASE](RELEASE.md)
